pub struct NaverTrend {
pub client: Client,
}Fields
client: ClientImplementations
Sourcepub fn get(&self, symbol: impl Into<String>) -> Result<Value>
pub fn get(&self, symbol: impl Into<String>) -> Result<Value>
Get Naver trend data with a daily frequency for a project that is associated with a given symbol. The values in response are normalized into a range from 0 to 100, where 0 corresponds to a minimum interest, and 100 corresponds to a maximum interest of users in Naver search engine.
Sourcepub fn symbols(&self) -> Result<Value>
pub fn symbols(&self) -> Result<Value>
Get crypto symbols that are accepted by Naver trend endpoint.