Struct Premium
Source pub struct Premium {
pub client: Client,
}
Returns the sorted list of categorical token tags currently indexed for the premium table filter. Updated on the aggregator’s tagstate reload cadence.
Get real-time premium (price difference) data across exchanges.
Get supported source exchanges for premium data.
Performs copy-assignment from
source.
Read more
Creates a new instance of the implementing type using the provided API key.
Creates a new instance of the implementing type using the provided API key and base URL.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Instruments this type with the provided [
Span], returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
Create a new
Policy that returns [
Action::Follow] only if
self and
other return
Action::Follow.
Read more
Create a new
Policy that returns [
Action::Follow] if either
self or
other returns
Action::Follow.
Read more
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.